Zuken API documentation

# Zuken

Small module that contains a variety of functions to help with script development Focus is on schematic/formboard development as that's what I've worked on at my own job

View Source

     1"""
     2Small module that contains a variety of functions to help with script development
     3Focus is on schematic/formboard development as that's what I've worked on at my own job
     4"""
     5
     6from .e3 import E3
     7from .e3 import Job
     8from .e3 import print
     9from .e3 import warn
    10from .e3 import error
    11from .e3 import message
    12from .e3 import verify
    13
    14from .devices import devicesOnSheet
    15from .devices import deviceFormboardId
    16from .devices import tableSymbolId
    17from .devices import coreIds
    18from .devices import filterByDeviceCode
    19from .devices import filterByDeviceAssignment
    20from .devices import filterByDeviceLocation
    21from .devices import filterByDeviceAttribute
    22from .devices import filterByDeviceClass
    23from .devices import filterByDeviceRegex
    24from .devices import filterByComponent
    25
    26from .symbols import placeSymbol
    27from .symbols import extractSymbolText
    28from .symbols import filterBySymbolName